<?php

add_action( 'after_setup_theme', 'vw_setup_schema_org' );
if ( ! function_exists( 'vw_setup_schema_org' ) ) {
	function vw_setup_schema_org() {
		if ( ! defined( 'VW_CONST_DISABLE_SCHEMA_ORG' ) ) {
			// add_filter( 'wp_get_attachment_image_attributes', 'vw_add_image_itemprop' );

			add_action( 'vw_action_post_schema', 'vw_itemprop_meta_post_date' );
			add_action( 'vw_action_post_schema', 'vw_add_main_entity_schema' );
			add_action( 'vw_action_post_schema', 'vw_add_featured_image_itemprop' );
		}
	}
}

/* -----------------------------------------------------------------------------
 * HTML Tag Schema
 * -------------------------------------------------------------------------- */
if ( ! function_exists( 'vw_html_tag_schema' ) ) {
	function vw_html_tag_schema() {
		// Is single post
		if( is_single() ) {
			// vw_itemtype( 'Article' );
		}

		// Is author page
		elseif( is_author() ) {
			vw_itemtype( 'ProfilePage' );
		}

		// Is search results page
		elseif( is_search() ) {
			vw_itemtype( 'SearchResultsPage' );
		}

		// Is archive
		elseif( is_archive() ) {
			vw_itemtype( 'CollectionPage' );
		}

		else {
			vw_itemtype( 'WebPage' );
		}

	}
}

if ( ! function_exists( 'vw_itemtype' ) ) {
	function vw_itemtype( $type ) {
		if ( empty( $type ) ) return;
		
		if ( ! defined( 'VW_CONST_DISABLE_SCHEMA_ORG' ) ) {
			echo ' itemscope itemtype="'.esc_url( 'http://schema.org/'.$type ).'" ';
		}
	}
}

if ( ! function_exists( 'vw_itemprop' ) ) {
	function vw_itemprop( $prop ) {
		if ( empty( $prop ) ) return;
		
		if ( ! defined( 'VW_CONST_DISABLE_SCHEMA_ORG' ) ) {
			echo ' itemprop="'.esc_attr( $prop ).'" ';
		}
	}
}

if ( ! function_exists( 'vw_itemprop_meta' ) ) {
	function vw_itemprop_meta( $prop, $content ) {
		if ( empty( $prop ) ) return;
		
		printf( '<meta itemprop="%s" content="%s"/>', $prop, $content );
	}
}

if ( ! function_exists( 'vw_get_itemtype' ) ) {
	function vw_get_itemtype( $type ) {
		if ( empty( $type ) ) return;
		
		if ( ! defined( 'VW_CONST_DISABLE_SCHEMA_ORG' ) ) {
			return ' itemscope itemtype="'.esc_url( 'http://schema.org/'.$type ).'" ';
		}
	}
}

if ( ! function_exists( 'vw_get_itemprop' ) ) {
	function vw_get_itemprop( $prop ) {
		if ( empty( $prop ) ) return;
		
		if ( ! defined( 'VW_CONST_DISABLE_SCHEMA_ORG' ) ) {
			return ' itemprop="'.esc_attr( $prop ).'" ';
		}
	}
}

if ( ! function_exists( 'vw_post_publisher' ) ) {
	function vw_post_publisher() {
		if ( ! defined( 'VW_CONST_DISABLE_SCHEMA_ORG' ) ) :
			$logo = vw_get_theme_option( 'logo' );
			if ( ! empty( $logo[ 'url' ] ) ):
		?>

		<div itemprop='publisher' itemscope='itemscope' itemtype='https://schema.org/Organization'>
			<meta itemprop='name' content='<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>'/>
			<div itemprop='logo' itemscope='itemscope' itemtype='https://schema.org/ImageObject'>
				<meta itemprop='url' content='<?php echo esc_url( $logo[ 'url' ] ); ?>'/>
				<meta itemprop='width' content='<?php echo esc_attr( $logo[ 'width' ] ) ?>'/>
				<meta itemprop='height' content='<?php echo esc_attr( $logo[ 'height' ] ) ?>'/>
			</div>
		</div>

		<?php
			endif;
		endif;
	}
}

if ( ! function_exists( 'vw_itemprop_meta_post_date' ) ) {
	function vw_itemprop_meta_post_date() {
		vw_itemprop_meta( 'datePublished', get_the_time('c') );
		vw_itemprop_meta( 'dateModified', get_the_modified_time('c') );
	}
}

if ( ! function_exists( 'vw_add_main_entity_schema' ) ) {
	function vw_add_main_entity_schema( $scope='') {
		if ( 'main-post' == $scope ) {
			?>
			<meta content="" itemscope itemprop="mainEntityOfPage"  itemType="https://schema.org/WebPage" itemid="<?php echo esc_url( get_permalink() ); ?>"/>
			<?php
		}
	}
}

if ( ! function_exists( 'vw_add_image_itemprop' ) ) {
	function vw_add_image_itemprop( $attr ) {
		$attr['itemprop'] = 'image';
		return $attr;
	}
}

if ( ! function_exists( 'vw_add_featured_image_itemprop' ) ) {
	function vw_add_featured_image_itemprop() {
		$image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
		?>
		<div itemprop='image' itemscope='itemscope' itemtype='https://schema.org/ImageObject'>
			<meta itemprop='url' content='<?php echo esc_url( $image[ 0 ] ); ?>'/>
			<meta itemprop='width' content='<?php echo esc_attr( $image[ 1 ] ) ?>'/>
			<meta itemprop='height' content='<?php echo esc_attr( $image[ 2 ] ) ?>'/>
		</div>
		<?php
	}
}